==> PyMSNt-0.6.tar.gz: PyMSNt/src/config.py <==
# Please read through all the options in this file

# The JabberID of the transport.
jid = "msn.host.com"
# The name of the transport (usually this shouldn't be changed)
name = "MSN Transport"
# The transport's version (usually this shouldn't be changed)
version = "0.6"

# The IP address of the main Jabberd server
mainServer = "127.0.0.1"
# The TCP port to connect to the Jabber server on (this is the default for Jabberd2)
port = "5347"
# The authentication token to use when connecting to the Jabber server
secret = "secret"


# Send email notification messages to users
mailNotifications = True

# Send greeting to all users at login (set to "" to disable)
sessionGreeting = "This is an experimental gateway, PyMSN-t. If you experience problems please contact James <james@delx.cjb.net>"


# Text that may get sent to the user. Useful for translations. Keep any %s symbols you see or you will have troubles later
registerText = "Please type your MSN Passport (user@hotmail.com) into the username field, your password and desired base nickname.\nFor more information see http://msn-transport.jabberstudio.org/users.html"
notLoggedIn = "Error. You must log into the transport before sending messages or subscription changes."
notRegistered = "Sorry. You do not appear to be registered with this transport. Please register and try again. If you are having trouble register please contact your Jabber administrator."
waitForLogin = "Sorry, this message cannot be delivered yet. Please try again when the transport has finished logging in."
groupchatInvite = "You have been invited into a groupchat on the legacy service. You must join this room to switch into groupchat mode %s.\nIf you do not join this room you will not be able to participate in the groupchat, but you will still appear to have joined it to contacts on the legacy service."
groupchatFailJoin1 = "You did not join the groupchat room %s.\nThe following users were in the groupchat:"
groupchatFailJoin2 = "You have been removed from this room on the legacy service. The following was said before you were disconnected, while you appeared to be in the groupchat to the contacts on the legacy service."
groupchatPrivateError = "Sorry. You cannot send private messages to users in this groupchat. Please instead add the user to your contact list and message them that way."
msnMaintenance = "Notification from Microsoft. The MSN Messenger network will be going down for maintenance."
msnMultipleLogin = "Your MSN account has been logged in elsewhere. Please logout at the other location and then reactivate the MSN transport."
msnNotVerified = "Your MSN passport %s, has not had it's email address verified. MSN users will not be able to see your nickname, and will be warned that your account may not be legitimate. Please see Microsoft for details."
msnLoginFailure = "MSN transport could not log into your MSN account %s. Please check that your password is correct. You may need to re-register the transport."
msnFailedMessage = "This message could not be delivered. Please check that the contact is online, and that their address on your contact list is correct.\nMessage was:\n\n"
msnInitialMail = "Hotmail notification\n\nUnread message in inbox: %s\nUnread messages in folders: %s"
msnRealtimeMail = "Hotmail notification\n\nFrom: %s <%s>\n Subject: %s"
msnDisconnected = "Disconnection from MSN servers: %s"



# Set this to True to get debugging output
debugOn = True
# Set the debug log file location here, (leave blank to output to the screen)
debugLog = ""

==> PyMSNt-0.6.1.tar.gz: PyMSNt/src/config.py <==
# Please read through all the options in this file

# The JabberID of the transport.
jid = "msn.host.com"
# The name of the transport (usually this shouldn't be changed)
name = "MSN Transport"
# The transport's version (usually this shouldn't be changed)
version = "0.6"

# The IP address of the main Jabberd server
mainServer = "127.0.0.1"
# The TCP port to connect to the Jabber server on (this is the default for Jabberd2)
port = "5347"
# The authentication token to use when connecting to the Jabber server
secret = "secret"


# Send email notification messages to users
mailNotifications = True

# Send greeting to all users at login (set to "" to disable)
sessionGreeting = "This is an experimental gateway, PyMSN-t. If you experience problems please contact James <james@delx.cjb.net>"


# Text that may get sent to the user. Useful for translations. Keep any %s symbols you see or you will have troubles later
registerText = "Please type your MSN Passport (user@hotmail.com) into the username field, your password and desired base nickname.\nFor more information see http://msn-transport.jabberstudio.org/users.html"
notLoggedIn = "Error. You must log into the transport before sending messages."
notRegistered = "Sorry. You do not appear to be registered with this transport. Please register and try again. If you are having trouble register please contact your Jabber administrator."
waitForLogin = "Sorry, this message cannot be delivered yet. Please try again when the transport has finished logging in."
groupchatInvite = "You have been invited into a groupchat on the legacy service. You must join this room to switch into groupchat mode %s.\nIf you do not join this room you will not be able to participate in the groupchat, but you will still appear to have joined it to contacts on the legacy service."
groupchatFailJoin1 = "You did not join the groupchat room %s.\nThe following users were in the groupchat:"
groupchatFailJoin2 = "You have been removed from this room on the legacy service. The following was said before you were disconnected, while you appeared to be in the groupchat to the contacts on the legacy service."
groupchatPrivateError = "Sorry. You cannot send private messages to users in this groupchat. Please instead add the user to your contact list and message them that way."
msnMaintenance = "Notification from Microsoft. The MSN Messenger network will be going down for maintenance."
msnMultipleLogin = "Your MSN account has been logged in elsewhere. Please logout at the other location and then reactivate the MSN transport."
msnNotVerified = "Your MSN passport %s, has not had it's email address verified. MSN users will not be able to see your nickname, and will be warned that your account may not be legitimate. Please see Microsoft for details."
msnLoginFailure = "MSN transport could not log into your MSN account %s. Please check that your password is correct. You may need to re-register the transport."
msnFailedMessage = "This message could not be delivered. Please check that the contact is online, and that their address on your contact list is correct.\nMessage was:\n\n"
msnInitialMail = "Hotmail notification\n\nUnread message in inbox: %s\nUnread messages in folders: %s"
msnRealtimeMail = "Hotmail notification\n\nFrom: %s <%s>\n Subject: %s"
msnDisconnected = "Disconnection from MSN servers: %s"



# Set this to True to get debugging output
debugOn = True
# Set the debug log file location here, (leave blank to output to the screen)
debugLog = ""
